@@ -1,8 +1,8 @@
 package Cassandra::Client::Connection;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Connection::VERSION = '0.11_003'; # TRIAL
+$Cassandra::Client::Connection::VERSION = '0.11_004'; # TRIAL
 
-$Cassandra::Client::Connection::VERSION = '0.11003';use 5.010;
+$Cassandra::Client::Connection::VERSION = '0.11004';use 5.010;
 use strict;
 use warnings;
 use vars qw/$BUFFER/;
@@ -182,7 +182,7 @@ sub execute_prepared {
         return $self->prepare_and_try_execute_again($callback, $queryref, $parameters, $attr, $exec_info);
     };
 
-    my $want_result_metadata= !$prepared->{result_metadata}{columns};
+    my $want_result_metadata= !$prepared->{decoder};
     my $row;
     if ($parameters) {
         eval {
@@ -380,9 +380,14 @@ sub prepare {
             }
 
             my $id= unpack_shortbytes($body);
+
+            my $metadata= eval { unpack_metadata($body) } or return $next->("Unable to unpack query metadata: $@");
+
             my ($encoder, $decoder);
-            my $metadata= eval { unpack_metadata2(my $old= $body); unpack_metadata($body) } or return $next->("Unable to unpack query metadata: $@");
-            my $resultmetadata= eval { ($decoder)= unpack_metadata2(my $old= $body); unpack_metadata($body) } or return $next->("Unable to unpack query result metadata: $@");
+            eval {
+                ($decoder)= unpack_metadata2($body);
+                1;
+            } or return $next->("Unable to unpack query result metadata: $@");
 
             eval {
                 $encoder= make_encoder($metadata);
@@ -392,7 +397,7 @@ sub prepare {
                 return $next->("Error while preparing query, couldn't compile encoder: $error");
             };
 
-            $self->{metadata}->add_prepared($query, $id, $metadata, $resultmetadata, $decoder, $encoder);
+            $self->{metadata}->add_prepared($query, $id, $metadata, $decoder, $encoder);
             return $next->();
         },
     ], sub {
@@ -410,21 +415,13 @@ sub decode_result {
     my $result_type= unpack('l>', substr($_[3], 0, 4, ''));
     if ($result_type == RESULT_ROWS) { # Rows
         my ($paging_state, $decoder);
-        my $metadata= eval { ($decoder, $paging_state)= unpack_metadata2(my $old= $_[3]); unpack_metadata($_[3]) } or return $callback->("Unable to unpack query metadata: $@");
+        eval { ($decoder, $paging_state)= unpack_metadata2($_[3]); 1 } or return $callback->("Unable to unpack query metadata: $@");
         $decoder= $prepared->{decoder} || $decoder;
 
-        my $rows;
-        eval {
-            $rows= $decoder->decode($_[3]);
-            1;
-        } or do {
-            my $error= $@ || "??";
-            return $callback->("Error while decoding row: $error");
-        };
         $callback->(undef,
             Cassandra::Client::ResultSet->new(
-                $rows,
-                [ map { $_->[2] } @{$prepared->{result_metadata}{columns} || $metadata->{columns}} ],
+                \$_[3],
+                $decoder,
                 $paging_state,
             )
         );
@@ -1104,7 +1101,7 @@ Cassandra::Client::Connection
 
 =head1 VERSION
 
-version 0.11_003
+version 0.11_004
 
 =head1 AUTHOR
 
