@@ -1,47 +1,35 @@
 package Cassandra::Client::ResultSet;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::ResultSet::VERSION = '0.11_003'; # TRIAL
+$Cassandra::Client::ResultSet::VERSION = '0.11_004'; # TRIAL
 
-$Cassandra::Client::ResultSet::VERSION = '0.11003';use 5.010;
+$Cassandra::Client::ResultSet::VERSION = '0.11004';use 5.010;
 use strict;
 use warnings;
 
 
 sub new {
-    my ($class, $rows, $headers, $next_page)= @_;
+    my ($class, $raw_data, $decoder, $next_page)= @_;
 
     return bless {
-        rows => $rows,
-        headers => $headers,
+        raw_data => $raw_data,
+        decoder => $decoder,
         next_page => $next_page,
     }, $class;
 }
 
 
 sub rows {
-    $_[0]{rows}
+    return $_[0]{rows} ||= $_[0]{decoder}->decode(${$_[0]{raw_data}}, 0);
 }
 
 
 sub row_hashes {
-    my $self= shift;
-    my $rows= $self->rows;
-    my @names= @{$self->column_names};
-
-    my @result;
-
-    for my $row (@$rows) {
-        my $newrow= {};
-        @{$newrow}{@names}= @$row;
-        push @result, $newrow;
-    }
-
-    return \@result;
+    return $_[0]{row_hashes} ||= $_[0]{decoder}->decode(${$_[0]{raw_data}}, 1);
 }
 
 
 sub column_names {
-    $_[0]{headers}
+    $_[0]{decoder}->column_names
 }
 
 
@@ -62,7 +50,7 @@ Cassandra::Client::ResultSet
 
 =head1 VERSION
 
-version 0.11_003
+version 0.11_004
 
 =head1 METHODS
 
